@@ -14,16 +14,6 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(***********************************************************************)
-(**                                                                   **)
-(**               WARNING WARNING WARNING                             **)
-(**                                                                   **)
-(** When you change this file, you must make the parallel change      **)
-(** in config.mlbuild                                                 **)
-(**                                                                   **)
-(***********************************************************************)
-
-
 (* The main OCaml version string has moved to ../VERSION *)
 let version = Sys.ocaml_version
 
@@ -40,9 +30,9 @@ let standard_library =
 
 let standard_runtime = "/usr/bin/ocamlrun"
 let ccomp_type = "cc"
-let bytecomp_c_compiler = "gcc -std=gnu99 -O2 -fno-strict-aliasing -fwrapv -Wall -D_FILE_OFFSET_BITS=64 -D_REENTRANT -fPIC"
+let bytecomp_c_compiler = "gcc -O2 -fno-strict-aliasing -fwrapv -D_FILE_OFFSET_BITS=64 -D_REENTRANT -fPIC"
 let bytecomp_c_libraries = "-lm  -ldl -lcurses -lpthread                  "
-let native_c_compiler = "gcc -std=gnu99 -O2 -fno-strict-aliasing -fwrapv -Wall -D_FILE_OFFSET_BITS=64 -D_REENTRANT"
+let native_c_compiler = "gcc -O2 -fno-strict-aliasing -fwrapv -D_FILE_OFFSET_BITS=64 -D_REENTRANT"
 let native_c_libraries = "-lm  -ldl"
 let native_pack_linker = "ld -r  -o "
 let ranlib = "ranlib"
@@ -58,18 +48,21 @@ let mkdll, mkexe, mkmaindll =
         let f i =
           let c = flexlink.[i] in
           if c = '/' then '\\' else c in
-        (String.init (String.length flexlink) f) ^ " %%FLEXLINK_FLAGS%%" in
+        (String.init (String.length flexlink) f) ^ " " in
       flexlink,
       flexlink ^ " -exe",
       flexlink ^ " -maindll"
     with Not_found ->
-      "gcc -shared", "gcc", "gcc -shared"
+      "gcc -shared", "gcc -O2 -fno-strict-aliasing -fwrapv -D_FILE_OFFSET_BITS=64 -D_REENTRANT", "gcc -shared"
   else
-    "gcc -shared", "gcc", "gcc -shared"
+    "gcc -shared", "gcc -O2 -fno-strict-aliasing -fwrapv -D_FILE_OFFSET_BITS=64 -D_REENTRANT", "gcc -shared"
 
+let profiling = true
 let flambda = false
 let safe_string = false
 
+let afl_instrument = false
+
 let exec_magic_number = "Caml1999X011"
 and cmi_magic_number = "Caml1999I021"
 and cmo_magic_number = "Caml1999O011"
@@ -87,7 +80,7 @@ and cmxa_magic_number =
 and ast_impl_magic_number = "Caml1999M020"
 and ast_intf_magic_number = "Caml1999N018"
 and cmxs_magic_number = "Caml2007D002"
-and cmt_magic_number = "Caml2012T008"
+and cmt_magic_number = "Caml2012T009"
 
 let load_path = ref ([] : string list)
 
@@ -113,8 +106,10 @@ let with_frame_pointers = false
 let spacetime = false
 let libunwind_available = false
 let libunwind_link_flags = ""
-let profinfo_width = 26
+let profinfo = false
+let profinfo_width = 0
 
+let ext_exe = ""
 let ext_obj = ".o"
 let ext_asm = ".s"
 let ext_lib = ".a"
@@ -135,6 +130,7 @@ let flexdll_dirs = [];;
 
 let print_config oc =
   let p name valu = Printf.fprintf oc "%s: %s\n" name valu in
+  let p_int name valu = Printf.fprintf oc "%s: %d\n" name valu in
   let p_bool name valu = Printf.fprintf oc "%s: %B\n" name valu in
   p "version" version;
   p "standard_library_default" standard_library_default;
@@ -150,10 +146,13 @@ let print_config oc =
   p "cc_profile" cc_profile;
   p "architecture" architecture;
   p "model" model;
+  p_int "int_size" Sys.int_size;
+  p_int "word_size" Sys.word_size;
   p "system" system;
   p "asm" asm;
   p_bool "asm_cfi_supported" asm_cfi_supported;
   p_bool "with_frame_pointers" with_frame_pointers;
+  p "ext_exe" ext_exe;
   p "ext_obj" ext_obj;
   p "ext_asm" ext_asm;
   p "ext_lib" ext_lib;
@@ -163,6 +162,7 @@ let print_config oc =
   p_bool "systhread_supported" systhread_supported;
   p "host" host;
   p "target" target;
+  p_bool "profiling" profiling;
   p_bool "flambda" flambda;
   p_bool "spacetime" spacetime;
   p_bool "safe_string" safe_string;
